==> orientdb-client-2.2.30-sources.jar: com/orientechnologies/orient/client/remote/OStorageRemoteConfiguration.java <==
/*
 *
 *  *  Copyright 2014 Orient Technologies LTD (info(at)orientechnologies.com)
 *  *
 *  *  Licensed under the Apache License, Version 2.0 (the "License");
 *  *  you may not use this file except in compliance with the License.
 *  *  You may obtain a copy of the License at
 *  *
 *  *       http://www.apache.org/licenses/LICENSE-2.0
 *  *
 *  *  Unless required by applicable law or agreed to in writing, software
 *  *  distributed under the License is distributed on an "AS IS" BASIS,
 *  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  *  See the License for the specific language governing permissions and
 *  *  limitations under the License.
 *  *
 *  * For more information: http://www.orientechnologies.com
 *
 */

package com.orientechnologies.orient.client.remote;

import com.orientechnologies.orient.core.config.OStorageConfiguration;

import java.nio.charset.Charset;

public class OStorageRemoteConfiguration extends OStorageConfiguration {

  private static final long serialVersionUID = -3850696054909943272L;
  private String networkRecordSerializer;

  public OStorageRemoteConfiguration(OStorageRemote oStorageRemote, String iRecordSerializer) {
    super(oStorageRemote, Charset.forName("UTF-8"));
    networkRecordSerializer = iRecordSerializer;
  }

  @Override
  public String getRecordSerializer() {
    return networkRecordSerializer;
  }

  @Override
  public int getRecordSerializerVersion() {
    return super.getRecordSerializerVersion();
  }

}

==> orientdb-client-2.2.37-sources.jar: com/orientechnologies/orient/client/remote/OStorageRemoteConfiguration.java <==
/*
 *
 *  *  Copyright 2014 Orient Technologies LTD (info(at)orientechnologies.com)
 *  *
 *  *  Licensed under the Apache License, Version 2.0 (the "License");
 *  *  you may not use this file except in compliance with the License.
 *  *  You may obtain a copy of the License at
 *  *
 *  *       http://www.apache.org/licenses/LICENSE-2.0
 *  *
 *  *  Unless required by applicable law or agreed to in writing, software
 *  *  distributed under the License is distributed on an "AS IS" BASIS,
 *  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  *  See the License for the specific language governing permissions and
 *  *  limitations under the License.
 *  *
 *  * For more information: http://www.orientechnologies.com
 *
 */

package com.orientechnologies.orient.client.remote;

import com.orientechnologies.orient.core.config.OStorageConfigurationImpl;

import java.nio.charset.Charset;

public class OStorageRemoteConfiguration extends OStorageConfigurationImpl {

  private static final long serialVersionUID = -3850696054909943272L;
  private String networkRecordSerializer;

  public OStorageRemoteConfiguration(OStorageRemote oStorageRemote, String iRecordSerializer) {
    super(oStorageRemote, Charset.forName("UTF-8"));
    networkRecordSerializer = iRecordSerializer;
  }

  @Override
  public String getRecordSerializer() {
    return networkRecordSerializer;
  }

  @Override
  public int getRecordSerializerVersion() {
    return super.getRecordSerializerVersion();
  }

}
